#******************************************************************************
#
# Tcl procedures for the automatic flux extraction of all _red.fits files in 
# the current directory
#
#******************************************************************************

#******************************************************************************
#
# The proc to be invoked from the FitsPrep shell command:
# 	fitsprep -AutoFluxEx [arg1] [arg2] ...[argn]
#
proc AutoFluxEx {args} {

    puts "fitsprep -AutoExec called with args $args"
    
    if {$args==""} {set args [glob -nocomplain *red.fits]}
	
    foreach file $args {
	if {![file exists $file]} {
	    puts "Cannot find file $file. Skipping!"
	    continue
	}

	set ext  [file extension $file]
	set root [file root $file]
	if {$ext!=".fits"} {
	    puts "File $file is not fits Skipping!"
	    continue
	}
	
	set fits_file ${root}.fits
	set out_file  ${root}_FlxEx.dat
		
	set err_flag [catch {FitsOps:FluxEx $fits_file $out_file} ]
	if {!$err_flag} {
	    puts "$fits_file -> $out_file "
	} else {
	    puts "Failed to extract flux for $fits_file!"
	}
    }
}
		
