#include "tcl.h"
#include "fitsTcl.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/* forward declarations */
int aaoshAppInit(Tcl_Interp *);

/*---------------------------------------------------------------------------*/

int main(int argc,char* argv[])
/*
 * Main routine for "aaosh" Tcl shell.
 *
 * This is the "tclsh" Tcl shell with certain AAO and 2dfdr procedures added.
 * Notice it is statically linked as to not depend on local Tcl installations.
 */
{
    /* Call Tcl main */
    Tcl_Main(argc,argv,aaoshAppInit);
	
    return 0; /* stop compiler from moaning */
}

/*---------------------------------------------------------------------------*/

int aaoshAppInit(Tcl_Interp *interp)
/*
 * This is a "hook" procedure that is invoked by Tcl_Main after its own
 * initialization and before entering the main loop to process commands.
 *
 * interp - handle to newly created interpreter
 */
{
    char *drcontrol_dir;
    char  resource_file[500];
    char  cmd[500];
    
    /* initialise fitsTcl */
    if (Fits_Init(interp) == TCL_ERROR)
	{
        return TCL_ERROR;
	}
    
    /* Get DRCONTROL_DIR directory, exit if undefined */
    drcontrol_dir = getenv("DRCONTROL_DIR");
    if (drcontrol_dir==NULL) return TCL_OK;

    /* Define resource file as "DRCONTROL_DIR/fitsprep/aaoshRcFile.tcl"
       Tcl startup code checks this variable and sources file if it exists */
    strcpy(resource_file,drcontrol_dir);
    strcat(resource_file,"/fitsprep/aaoshRcFile.tcl");
    Tcl_SetVar(interp,"tcl_rcFileName",resource_file,TCL_GLOBAL_ONLY);

    /* Add "DRCONTROL_DIR/tcl" to auto_path variable
       This variable contains valid Tcl list giving directories to
       search during auto-load operations */
    strcpy(cmd,"lappend auto_path ");
    strcat(cmd,drcontrol_dir);
    strcat(cmd,"/tcl");
    Tcl_Eval(interp,cmd);
    
    /* Define tcl_library location as "DRCONTROL_DIR/tcl"
       This variable holds name of directory
       containing system library of Tcl scripts */
    strcpy(cmd,"set tcl_library ");
    strcat(cmd,drcontrol_dir);
    strcat(cmd,"/tcl");
    Tcl_Eval(interp,cmd);

    /* Source tcl library init.tcl
       I don't know why we have to do this
       as tclsh is supposed to do it on startup (mnb) */
    strcpy(cmd,"source [file join $tcl_library init.tcl]");
    Tcl_Eval(interp,cmd);
    
    return TCL_OK;
}
