#                 ===============================
#                     aaosh Resource File
#                 ===============================

# -------------------------------------------------------------------------
# COMMENTS:
# --------
# This is the aaosh resource file
#
# -------------------------------------------------------------------------

#******************************************************************************
#
# Search for matching command (used below).
#
# Arguments
#   cmdstr  - command to match
#
# Returns list of matching commands
#
proc fitsprep_CmdMatch {cmdstr} {

    set poss_list ""

    # if given string matches command add it to poss_list
    if {[info commands $cmdstr]!=""} {
	lappend poss_list $cmdstr
    }

    # Now look for FitsOps: procs with suffix that match (ignoring case)
    set match_prefix "FitsOps:"
    set idx [string length $match_prefix]
    set lcase_cmdstr [string tolower $cmdstr]
    set fitsops_cmds [info commands "${match_prefix}*"]
    foreach cmd $fitsops_cmds {
	set idname [string range $cmd $idx end]
	set idname [string tolower $idname]
	if {$idname==$lcase_cmdstr} {
	    lappend poss_list $cmd
	}
    }

    return $poss_list
}


#******************************************************************************
#
# AAOSH main program
#
# No argument indicates go to interactive.
# Argument with "-" prefix indicates a command to be executed.
# Non-prefixed argument indicates Tcl filename to be sourced.
#

# Setup prompts
proc fitsprep_tclPrompt1 {} {puts -nonewline "AAO:sh> "}
proc fitsprep_tclPrompt2 {} {puts -nonewline "              "}
set tcl_prompt1 fitsprep_tclPrompt1
set tcl_prompt2 fitsprep_tclPrompt2 


set drcontrol_dir $env(DRCONTROL_DIR)

global FitsPrepNewVersion
if {[info var FitsPrepNewVersion] != ""} {
    # Find fitsprep.tcl in DRCONTROL_DIR directory.
    set aaosh_lib_file [file join $drcontrol_dir fitsprep.tcl]
} else {
    # Determine directory that should contains the aaosh_lib.tcl file.  Old code (prior to 
    #  autoconfigure version of 2dFdr), wants aaosh_lib.tcl
    set fitsprep_home  [file join $drcontrol_dir fitsprep]
    set aaosh_lib_file [file join $fitsprep_home aaosh_lib.tcl]
}

# Now source aaosh_lib.tcl which should load up the FitsOps procedure library
if {[catch {source $aaosh_lib_file} result]} {
    puts "Failure in loading FitsPrep libaries:"
    set err_lines   [split $errorInfo \n]
    set n_lines     [llength $err_lines]
    set err_lines   [lrange $err_lines 0 [expr $n_lines-6]]
    set err_message [join $err_lines \n]
    puts $err_message
    exit
}


# If no arguments then return to interactive mode
if {$argc==0} {
    puts ""
    puts "                *************************************"
    puts "                ********  AAO fitsTcl Shell  ********"
    puts "                *************************************"
    puts ""
    return
}

# There are arguments. Check if this is a single command call option
# or option to source a tcl script.
set arg0 $argv

# If arg0 begins with a "-" then assume that is to call a tcl procedure
if {[string range $arg0 0 0]=="-"} {

    set tcl_interactive 0

    set cmdname [string range $arg0 1 end]
    
    # Check that this command exists
    set cmd_matches [fitsprep_CmdMatch $cmdname]
    set n_matches [llength $cmd_matches]
    if {$n_matches==0} {
	puts "Invalid command $arg0"
	exit
    }
    if {$n_matches>1} {
	puts "Command $cmdname too ambiguous: $cmd_matches ?"
	exit
    }
    set procname [lindex $cmd_matches 0]
	
    # Evaluate this proc, but catch any errors
    if {[catch {eval "$procname $argv"} result]} {
	# Print the error info but skip the last three lines as
	# this is just about how it is from "eval "$procname $argv"
	set err_lines   [split $errorInfo \n]
	set n_lines     [llength $err_lines]
	set err_lines   [lrange $err_lines 0 [expr $n_lines-4]]
	set err_message [join $err_lines \n]
	puts $err_message
    }
    exit
}	

# Assume that arg0 is a filename of a tcl script to source

if {![file exists $arg0]} {
    puts "cannot find file $arg0"
    exit
}

# arg0 is a real file so source it but catch any errors
set tcl_interactive 0
if {[catch {source $arg0} result]} {
    # Print the error info but skip the last two lines as
    # this is just about how it is from "source $arg0"
    set err_lines   [split $errorInfo \n]
    set n_lines     [llength $err_lines]
    set err_lines   [lrange $err_lines 0 [expr $n_lines-3]]
    set err_message [join $err_lines \n]
    puts $err_message
} 

exit
