/*
 * aaowish_new.c, replaces aaowish.c in autoconfigure version of fitspre subystem. 
 *   aaowish_new.c will be removed when we complete the move to using autocofigure. 
 */

#include "tcl.h"
#include "tk.h"
#include "fitsTcl.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/* forward declarations */
static int aaowishAppInit(Tcl_Interp *);
extern void DrTkRun(int argc,char* argv[], Tcl_AppInitProc *appInitProc);


/*---------------------------------------------------------------------------*/

int main(int argc,char* argv[])
/*
 * Main routine for "aaowish" Tcl shell.
 *
 * This is the "wish" Tk shell with certain AAO and 2dfdr procedures added.
 * Notice it is statically linked as to not depend on local Tcl/Tk
 * installations.
 */
{
   /* Call Tk main via 2dFdr code which sets up the environment variables etc. */
    DrTkRun(argc,argv,aaowishAppInit);
	
    return 0; /* stop compiler from moaning */
}

/*---------------------------------------------------------------------------*/

static int aaowishAppInit(Tcl_Interp *interp)
/*
 * This is a "hook" procedure that is invoked by Tcl_Main after its own
 * initialization and before entering the main loop to process commands.
 *
 * interp - handle to newly created interpreter
 */
{
    char *drcontrol_dir;
    char  resource_file[500];
    char  cmd[500];
     
   /* initialise Tcl package */
    if (Tcl_Init(interp) == TCL_ERROR)
    {
        return TCL_ERROR;
    }
    
   /* initialise fitsTcl package */
    if (Fits_Init(interp) == TCL_ERROR)
    {
        return TCL_ERROR;
    }
    
   /* initialise Tk package */
    if (Tk_Init(interp) == TCL_ERROR)
    {
        return TCL_ERROR;
    }

   /* initialise pgplot tcl package */
    if (Pgplot_tcl_Init(interp) == TCL_ERROR)
    {
        return TCL_ERROR;
    }

        
    /* Get DRCONTROL_DIR directory, exit if undefined */
    drcontrol_dir = getenv("DRCONTROL_DIR");
    if (drcontrol_dir==NULL) return TCL_OK;

    /* Define resource file as aaoshRcFile.tcl */
    strcpy(resource_file,drcontrol_dir);
    strcat(resource_file,"/aaowishRcFile.tcl");
    Tcl_SetVar(interp,"tcl_rcFileName",resource_file,TCL_GLOBAL_ONLY);

    /* Ensure the aaowishRcFile.tcl knows we are running the autoconfigure
     * version of this*/
    Tcl_SetVar(interp,"AAOWishNewVersion","1",TCL_GLOBAL_ONLY);


    /* Source the tcl library. 
       I don't know why we have to do this
       as tclsh is supposed to do it on startup (mnb) */
    strcpy(cmd,"source [file join $tcl_library init.tcl]");
    Tcl_Eval(interp,cmd);
    
    /* Source our aaowish tcl library */
    strcpy(cmd,"source [file join $env(DRCONTROL_DIR) aaowish_lib.tcl]");
    Tcl_Eval(interp,cmd);


    return TCL_OK;
}
