#                 ===============================
#                     aaowish Resource File
#                 ===============================

#******************************************************************************
#
# Search for matching command (used below).
#
# Arguments
#   cmdstr  - command to match
#
# Returns list of matching commands
#
proc fitsprep_CmdMatch {cmdstr} {

    set poss_list ""

    # if given string matches command add it to poss_list
    if {[info commands $cmdstr]!=""} {
	lappend poss_list $cmdstr
    }

    # Now look for FitsOps: procs with suffix that match (ignoring case)
    set match_prefix "FitsOps:"
    set idx [string length $match_prefix]
    set lcase_cmdstr [string tolower $cmdstr]
    set fitsops_cmds [info commands "${match_prefix}*"]
    foreach cmd $fitsops_cmds {
	set idname [string range $cmd $idx end]
	set idname [string tolower $idname]
	if {$idname==$lcase_cmdstr} {
	    lappend poss_list $cmd
	}
    }

    return $poss_list
}


#******************************************************************************
#
# AAOWISH main program
#
# No argument indicates go to interactive.
# Argument with "-" prefix indicates a command to be executed.
# Non-prefixed argument indicates Tcl filename to be sourced.
#

# Setup prompt procs
proc fitsprep_tclPrompt1 {} {puts -nonewline "AAO:wish> "}
proc fitsprep_tclPrompt2 {} {puts -nonewline "              "}
set tcl_prompt1 fitsprep_tclPrompt1
set tcl_prompt2 fitsprep_tclPrompt2 

# Check if this is old aaowish and if so display a warning.
global AAOWishNewVersion
if {[info var AAOWishNewVersion] != ""} {
} else {
    puts "Old version code. Warning this is no longer being supported!"
}


# If no arguments then return to interactive mode
if {$argc==0} {

    # put up banner and return
    puts ""
    puts "                ******************************************"
    puts "                ********  AAO fitsTcl Wish Shell  ********"
    puts "                ******************************************"
    puts ""
    return
}

# Here there are arguments
# Check if single command call option or option to source tcl script
set arg0 $argv

# Does argument begin with "-" If so then assume that what follows is a cmd
if {[string range $arg0 0 0]=="-"} {

    # Yes, assume it's call Tcl procedure
    set tcl_interactive 0
    set cmdname [string range $arg0 1 end]
    
    # Check command exists
    set cmd_matches [fitsprep_CmdMatch $cmdname]
    set n_matches [llength $cmd_matches]
    if {$n_matches==0} {
	puts "Invalid command $arg0"
	exit
    }

    # Check command is unique
    if {$n_matches>1} {
	puts "Command $cmdname too ambiguous: $cmd_matches ?"
	exit
    }

    # So no of command matches is 1 and this is the command to be executed
    set procname [lindex $cmd_matches 0]
	
    # Evaluate this proc, but catch any errors
    if {[catch {eval "$procname $argv"} result]} {
	# Print the error info but skip the last three lines as
	# this is just about how it is from "eval "$procname $argv"
	set err_lines   [split $errorInfo \n]
	set n_lines     [llength $err_lines]
	set err_lines   [lrange $err_lines 0 [expr $n_lines-4]]
	set err_message [join $err_lines \n]
	puts $err_message
    }
    exit
}	

# Assume arg0 is filename of Tcl script to source
if {![file exists $arg0]} {
    puts "cannot find file $arg0"
    exit
}

# arg0 is real file so source it but catch any errors
set tcl_interactive 0
if {[catch {source $arg0} result]} {
    # Print the error info but skip the last two lines as
    # this is just about how it is from "source $arg0"
    set err_lines   [split $errorInfo \n]
    set n_lines     [llength $err_lines]
    set err_lines   [lrange $err_lines 0 [expr $n_lines-3]]
    set err_message [join $err_lines \n]
    puts $err_message
} 

exit
