#include "tcl.h"
#include "tk.h"
#include "fitsTcl.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/* forward declarations */
int aaowishAppInit(Tcl_Interp *);

/*---------------------------------------------------------------------------*/

int main(int argc,char* argv[])
/*
 * Main routine for "aaowish" Tcl shell.
 *
 * This is the "wish" Tk shell with certain AAO and 2dfdr procedures added.
 * Notice it is statically linked as to not depend on local Tcl/Tk
 * installations.
 */
{
    /* Call Tk main */
    Tk_Main(argc,argv,aaowishAppInit);
	
    return 0; /* stop compiler from moaning */
}

/*---------------------------------------------------------------------------*/

int aaowishAppInit(Tcl_Interp *interp)
/*
 * This is a "hook" procedure that is invoked by Tcl_Main after its own
 * initialization and before entering the main loop to process commands.
 *
 * interp - handle to newly created interpreter
 */
{
    char *drcontrol_dir;
    char  resource_file[500];
    char  library_dir[500];
    char  cmd[500];


    /* Get DRCONTROL_DIR directory, exit if undefined */
    drcontrol_dir = getenv("DRCONTROL_DIR");
    if (drcontrol_dir==NULL) printf("env var DRCONTROL_DIR is undefined\n");
    if (drcontrol_dir==NULL) return TCL_OK;
    
    /* Define location of the tcl library needed for Tk init*/
    strcpy(library_dir,drcontrol_dir);
    strcat(library_dir,"/tcl");
    Tcl_SetVar(interp,"tcl_library",library_dir,TCL_GLOBAL_ONLY);
    
    /* Define location of the tk library needed for Tk init*/
    strcpy(library_dir,drcontrol_dir);
    strcat(library_dir,"/tk");
    Tcl_SetVar(interp,"tk_library",library_dir,TCL_GLOBAL_ONLY);
      
   /* initialise Tcl package */
    if (Tcl_Init(interp) == TCL_ERROR)
    {
        return TCL_ERROR;
    }
    
   /* initialise fitsTcl package */
    if (Fits_Init(interp) == TCL_ERROR)
    {
        return TCL_ERROR;
    }
    
   /* initialise Tk package */
    if (Tk_Init(interp) == TCL_ERROR)
    {
        return TCL_ERROR;
    }
    
   /* initialise Tkhtml package */
/*    if (Tkhtml_Init(interp) == TCL_ERROR)
    {
        return TCL_ERROR;
    }
*/
    /* Define resource file as aaoshRcFile.tcl */
    strcpy(resource_file,drcontrol_dir);
    strcat(resource_file,"/fitsprep/aaowishRcFile.tcl");
    Tcl_SetVar(interp,"tcl_rcFileName",resource_file,TCL_GLOBAL_ONLY);

    /* Define auto_path variable */
    strcpy(cmd,"lappend auto_path ");
    strcat(cmd,drcontrol_dir);
    strcat(cmd,"/tcl");
    Tcl_Eval(interp,cmd);
    
   
    /* Source the tcl library. 
       I don't know why we have to do this
       as tclsh is supposed to do it on startup (mnb) */
    strcpy(cmd,"source [file join $tcl_library init.tcl]");
    Tcl_Eval(interp,cmd);
    
    return TCL_OK;
}
